Opbeat
======

.. image:: https://api.travis-ci.org/opbeat/opbeat_python.svg?branch=master
    :target: https://travis-ci.org/opbeat/opbeat_python
    :alt: Build Status
    
.. image:: https://pypip.in/version/opbeat/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/opbeat/
    :alt: Latest Version

.. image:: https://pypip.in/py_versions/opbeat/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/opbeat/
    :alt: Supported Python versions


This is the official Python module for `Opbeat <https://opbeat.com/>`_.
It provides full out-of-the-box support for many of the popular frameworks,
including Django, and Flask. Opbeat also includes drop-in support for any
WSGI-compatible web application.

Your application doesn't live on the web? No problem! Opbeat is easy to use in
any Python application.



Resources
---------

* `Documentation <https://www.opbeat.com/docs>`_
* `Bug Tracker <https://github.com/opbeat/opbeat_python/issues>`_
* `Code <https://github.com/opbeat/opbeat_python>`_
